// set the dimensions and margins of the graph
const margin = { top: 10, right: 30, bottom: 30, left: 60 },
  width = 900 - margin.left - margin.right,
  height = 400 - margin.top - margin.bottom;

// append the svg object to the body of the page
const svg = d3
  .select('#my_dataviz')
  .append('svg')
  .attr('width', width + margin.left + margin.right)
  .attr('height', height + margin.top + margin.bottom)
  .append('g')
  .attr(
    'transform',
    `translate(${margin.left}, ${margin.top})`,
  );

//Read the data
d3.csv(
  'https://raw.githubusercontent.com/bepnye/CP341/main/world-data-2023.csv',
).then(function (data) {
  // Add X axis
  console.log(data);
  const x = d3
    .scaleLinear()
    .domain([0, 50])
    .range([0, width]);
  svg
    .append('g')
    .attr('transform', `translate(0, ${height})`)
    .call(d3.axisBottom(x));

  // Add Y axis
  const y = d3
    .scaleLinear()
    .domain([0, 100])
    .range([height, 0]);
  svg.append('g').call(d3.axisLeft(y));

  // Add dots
  svg
    .append('g')
    .selectAll('dot')
    .data(data)
    .join('circle')
    .attr('cx', function (d) {
      return x(d['Birth Rate']);
    })
    .attr('cy', function (d) {
      return y(d['Calling Code']);
    })
    .attr('r', (d) => d['Infant mortality'])
    .style('fill', '#69b3a2')
    .on('mouseenter', (e, d) => {
      console.log(e);
      console.log(d);
    });
});
